@@ -1,7 +1,7 @@
 from prodigy.gameData import gameData
 from prodigy.gameStatus import gameStatus
 from prodigy.getAsset import get_asset
-from prodigy.player import player, updatePlayer
+from prodigy.player import player, update_player
 from prodigy.prodigy import Prodigy
 from prodigy.tokenify import tokenify
 
@@ -10,7 +10,7 @@ __all__ = [
     "gameStatus",
     "get_asset",
     "player",
-    "updatePlayer",
+    "update_player",
     "Prodigy",
     "tokenify"
 ]
